#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2014 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using HeuristicLab.Common;
using HeuristicLab.Core.Views;
using HeuristicLab.MainForm;
using System;
using System.Windows.Forms;

namespace HeuristicLab.Core.Networks.Views {
  [View("MessageValue View")]
  [Content(typeof(MessageValue<>), true)]
  [Content(typeof(IMessageValue<>), false)]
  [Content(typeof(IMessageValue), false)]
  public partial class MessageValueView : ItemView {
    public new IMessageValue Content {
      get { return (IMessageValue)base.Content; }
      set { base.Content = value; }
    }

    public MessageValueView() {
      InitializeComponent();
    }

    protected override void DeregisterContentEvents() {
      Content.ValueChanged -= Content_ValueChanged;
      base.DeregisterContentEvents();
    }

    protected override void RegisterContentEvents() {
      base.RegisterContentEvents();
      Content.ValueChanged += Content_ValueChanged;
    }

    protected override void OnContentChanged() {
      base.OnContentChanged();
      if (Content == null) {
        dataTypeTextBox.Text = string.Empty;
        valueViewHost.Content = null;
      } else {
        dataTypeTextBox.Text = Content.DataType.GetPrettyName();
        valueViewHost.ViewType = null;
        valueViewHost.Content = Content.Value;
      }
    }

    protected override void SetEnabledStateOfControls() {
      base.SetEnabledStateOfControls();
      dataTypeTextBox.Enabled = Content != null;
      valueGroupBox.Enabled = Content != null;
    }
    protected virtual void Content_ValueChanged(object sender, System.EventArgs e) {
      if (InvokeRequired)
        Invoke(new EventHandler(Content_ValueChanged), sender, e);
      else {
        valueViewHost.ViewType = null;
        valueViewHost.Content = Content.Value;
      }
    }
  }
}
